/**
 * @(#) LifeCycleMBean.java
 *
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: LifeCycleMBean.java 69 2006-01-17 16:00:26Z rmarins $
 * -------------------------------------------------------------------------
 */

//
// This source code implements specifications defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//

package javax.jbi.management;

/**
 * LifeCycleMBean is a base interface that defines standard life cycle controls
 * for JBI Framework services and JBI Components (bindings and engines).
 * 
 * @author JSR208 Expert Group
 */
public interface LifeCycleMBean {

	/**
     * Value returned by {@link LifeCycleMBean#getCurrentState()} for a shutdown
     * component.
     */
	public static final java.lang.String SHUTDOWN = "Shutdown";

	/**
     * Value returned by {@link LifeCycleMBean#getCurrentState()} for a started
     * component.
     */
	public static final java.lang.String STARTED = "Started";

	/**
     * Value returned by {@link LifeCycleMBean#getCurrentState()} for a stopped
     * component.
     */
	public static final java.lang.String STOPPED = "Stopped";

	/**
     * Value returned by {@link LifeCycleMBean#getCurrentState()} for a
     * component in an unknown state.
     */
	public static final java.lang.String UNKNOWN = "Unknown";

	/**
	 * Get the current state of this managed component.
	 * 
	 * @return the current state of this managed component (must be one of the
	 *         string constants defined by this interface)
	 */
	public java.lang.String getCurrentState();

	/**
     * Shut down the item. This releases resources, returning the item to an
     * unitialized state.
     * 
     * @throws javax.jbi.JBIException
     *             if the item fails to shut down
     */
	public void shutDown() throws javax.jbi.JBIException;

	/**
	 * Start the item.
	 * 
	 * @throws javax.jbi.JBIException
	 *             if the item fails to start
	 */
	public void start() throws javax.jbi.JBIException;

	/**
	 * Stop the item. This suspends current messaging activities.
	 * 
	 * @throws javax.jbi.JBIException
	 *             if the item fails to stop
	 */
	public void stop() throws javax.jbi.JBIException;
}
